# Quotes to Scrape

Login

“The world as we have created it is a process of our thinking. It cannot be changed without changing our thinking.” by Albert Einstein (about)
Tags: change deep-thoughts thinking world
“It is our choices, Harry, that show what we truly are, far more than our abilities.” by J.K. Rowling (about)
Tags: abilities choices
“There are only two ways to live your life. One is as though nothing is a miracle. The other is as though everything is a miracle.” by Albert Einstein (about)
Tags: inspirational life live miracle miracles
“The person, be it gentleman or lady, who has not pleasure in a good novel, must be intolerably stupid.” by Jane Austen (about)
Tags: aliteracy books classic humor
“Imperfection is beauty, madness is genius and it's better to be absolutely ridiculous than absolutely boring.” by Marilyn Monroe (about)
Tags: be-yourself inspirational
“Try not to become a man of success. Rather become a man of value.” by Albert Einstein (about)
Tags: adulthood success value
“It is better to be hated for what you are than to be loved for what you are not.” by André Gide (about)
Tags: life love
“I have not failed. I've just found 10,000 ways that won't work.” by Thomas A. Edison (about)
Tags: edison failure inspirational paraphrased
“A woman is like a tea bag; you never know how strong it is until it's in hot water.” by Eleanor Roosevelt (about)
Tags: misattributed-eleanor-roosevelt
“A day without sunshine is like, you know, night.” by Steve Martin (about)
Tags: humor obvious simile

## Top Ten tags

love inspirational life humor books reading friendship friends truth simile